# coding: utf-8
from json import dumps
import traceback
from pyeole.lock import acquire, release, is_locked
from eoleaaf.sambatranslator import SambaExport

from logging import getLogger
aaflog = getLogger("AAF")

from .action import describe as _describe, submit as _submit

def _send_error_message(msg, remove_lock=True):
    return _send_message(u"Erreur {}".format(msg), remove_lock, 'error')


def _send_message(msg, level='info', remove_lock=True):
    if remove_lock:
        try:
            release('importaaf', level='system')
        except:
            traceback.print_exc()
            pass
    return dumps({'message': {'type': level, 'text': msg}})


def launch(**kwargs):
    aaflog.info(20*'*')
    aaflog.info("*** Début de l'importation des comptes et des groupes")
    try:
        acquire('importaaf', level="system")
    except Exception as err:
        return _send_error_message("impossible de lancer l'import complet : {}".format(err), False)

    try:
        ##export TDB_NO_FSYNC=1
        samba_import = SambaExport(aaflog, debug=True)
        samba_import.run()
    except Exception as err:
        traceback.print_exc()
        return _send_error_message("à l'importation des comptes dans l'annuaire : {}".format(err))
    aaflog.info("*** Fin de l'importation des comptes et des groupes")
    aaflog.info(20*'*')
    return _send_message('Importation effectuée')


def describe(*args, **kwargs):
    if is_locked(name='importaaf', level='system'):
        return _send_error_message("un import AAF est en cours", False)
    return _describe(*args, **kwargs)


def submit(*args, **kwargs):
    if is_locked(name='importaaf', level='system'):
        return _send_error_message("une action AAF est en cours", False)
    return launch()
__CUSTOM_MODULES__ = ('launch',)
